]> Sergey Matveev's repositories - nnn.git/commitdiff
More appropriate enum name
authorArun Prakash Jana <engineerarun@gmail.com>
Sat, 15 Aug 2020 14:51:22 +0000 (20:21 +0530)
committerArun Prakash Jana <engineerarun@gmail.com>
Sat, 15 Aug 2020 14:51:22 +0000 (20:21 +0530)
src/nnn.c
src/nnn.h

index 8a6cb3bf29f52a8bc19e9d364c8229d9a6a91ca1..edaf37113b5515fee7289fba51d892f2154398a6 100644 (file)
--- a/src/nnn.h
+++ b/src/nnn.h
@@ -37,7 +37,7 @@
 /* Supported actions */
 enum action {
        SEL_BACK = 1,
-       SEL_GOIN,
+       SEL_OPEN,
        SEL_NAV_IN,
        SEL_NEXT,
        SEL_PREV,
@@ -123,8 +123,8 @@ static struct key bindings[] = {
        { KEY_LEFT,       SEL_BACK },
        { 'h',            SEL_BACK },
        /* Inside or select */
-       { KEY_ENTER,      SEL_GOIN },
-       { '\r',           SEL_GOIN },
+       { KEY_ENTER,      SEL_OPEN },
+       { '\r',           SEL_OPEN },
        /* Pure navigate inside */
        { KEY_RIGHT,      SEL_NAV_IN },
        { 'l',            SEL_NAV_IN },
--- a/src/nnn.c
+++ b/src/nnn.c
@@ -5841,7 +5841,7 @@ nochange:
                                    &mousetimings[currentmouse]);
                                mousedent[currentmouse] = cur;
 
/* Single click just selects, double click falls through to SEL_GOIN */
                                if ((mousedent[0] != mousedent[1]) ||
                                  (((_ABSSUB(mousetimings[0].tv_sec, mousetimings[1].tv_sec) << 30)
                                  + (_ABSSUB(mousetimings[0].tv_nsec, mousetimings[1].tv_nsec)))
@@ -5859,7 +5859,7 @@ nochange:
 #endif
                        // fallthrough
                case SEL_NAV_IN: // fallthrough
-               case SEL_GOIN:
+               case SEL_OPEN:
                        /* Cannot descend in empty directories */
                        if (!ndents)
                                goto begin;
@@ -5893,7 +5893,7 @@ nochange:
                        }
 
                        /* If opened as vim plugin and Enter/^M pressed, pick */
-                       if (g_state.picker && sel == SEL_GOIN) {
+                       if (g_state.picker && sel == SEL_OPEN) {
                                appendfpath(newpath, mkpath(path, pent->name, newpath));
                                writesel(pselbuf, selbufpos - 1);
                                return EXIT_SUCCESS;
@@ -5841,7 +5841,7 @@ nochange:
                                mousedent[currentmouse] = cur;
 
-                               /* Single click just selects, double click falls through to SEL_GOIN */
+                               /* Single click just selects, double click falls through to SEL_OPEN */
                                if ((mousedent[0] != mousedent[1]) ||
                                  (((_ABSSUB(mousetimings[0].tv_sec, mousetimings[1].tv_sec) << 30)
index 57c8649f4a5f18a5e944abaa8632b3fc84c8127b..40f04ac3402f8a54750117b0fb2dd7d3bd2bacd8 100644 (file)